@@ -5,9 +5,11 @@ from SAPOFTO import SAPOFTO
 
 def schedule(args):
     session_archetype = input('Please input the session type for this session:')
-    skeleton = SAPOFTO.SAPOFTO(key='SKELETON',filename='sessionskeletons.org')
+    print(session_archetype)
+    skeleton = SAPOFTO.SAPOFTO(key='SKELETON',filename='session_skeletons.org')
+    print(skeleton.keys())
     roles_node = skeleton[session_archetype]['SUBJECT ROLES']
-    for role_name in roles_node.key():
+    for role_name in roles_node.keys():
         subject_id = input('Please enter a user ID to fill the role of ' + role_name + ' for this session:')
         if subject_id != '':            
             role_nodes[role_name].setValue(subject_id)
